@@ -10,16 +10,22 @@ def slice_of_data(
     slice_index=0,
     volume_normalization: bool = True,
 ):
+    lower_index = int(slice_index * (len(self.r_grid) - 1))
+    upper_index = int((slice_index + 1) * (len(self.r_grid) - 1))
+
     if volume_normalization:
-        dataset = dataset.flatten() / self.volumes.T.reshape(-1, 3).flatten()
-    else:
-        dataset = dataset.flatten()
+        data_slice = dataset.flatten().reshape(-1, len(self.z_grid) - 1, order="F")[
+            lower_index:upper_index
+        ]
+        data_slice = data_slice / self.volumes[:, 1, :]
 
-    data_slice = dataset.T.reshape(-1, 3)
+        return np.rot90(data_slice)
 
-    data_slice = data_slice[slice_index :: self.dimension[1]]
+    data_slice = dataset.flatten().reshape(-1, len(self.z_grid) - 1, order="F")[
+        lower_index:upper_index
+    ]
 
-    return np.flip(data_slice, axis=0)
+    return np.rot90(data_slice)
 
 
 def get_mpl_plot_extent(self):
